/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.applicationprocessor.configmanager;

import static org.tinygroup.logger.LogLevel.INFO;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.io.input.BOMInputStream;
import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;
import org.tinygroup.vfs.FileObject;
import org.tinygroup.xmlparser.node.XmlNode;
import org.tinygroup.xmlparser.parser.XmlStringParser;


/**
 * tiny filter处理器配置管理对象
 * @author renhui
 *
 */
public class TinyFiterConfigManager {
	
    public static final String TINY_FILTER_CONFIGMANAGER = "tinyFilterConfigManager";


	private List<XmlNode> configs=new ArrayList<XmlNode>();
	
	private XmlNode applicationConfig;
	 
	private static Logger logger = LoggerFactory
		.getLogger(TinyFiterConfigManager.class);
	
	 
	 public void  addConfig(FileObject fileObject){
		 String filePath=fileObject.getPath();
		 logger.logMessage(INFO, "正在加载tiny-filter处理器配置文件[{0}] ....",filePath
					);
		 BOMInputStream inputStream = null;
			try {
				inputStream = new BOMInputStream(fileObject.
						getInputStream());
				byte[] bytes = new byte[inputStream.available()];
				inputStream.read(bytes);
				inputStream.close();
				fileObject.getInputStream().close();
				String content = new String(bytes, "UTF-8");
				logger.logMessage(INFO, "tiny-filter处理器配置文件<{0}>加载完成。.",
						filePath);
				XmlNode root = new XmlStringParser().parse(content)
						.getRoot();
				configs.add(root);
			} catch (Exception e) {
				logger.errorMessage("载入tiny-filter配置文件<{}>时发生异常", e,
						filePath);
				throw new RuntimeException(e);
			}
		 
	 }
	 
	public void setApplicationConfig(XmlNode xmlNode){
		 this.applicationConfig=xmlNode;
	}

	public XmlNode getApplicationConfig(){
		return applicationConfig;
	}

	public List<XmlNode> getConfigs() {
		return configs;
	}
   
	
	
	
}
