/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.applicationprocessor.processor;

import java.util.List;

import org.tinygroup.annotation.impl.AnnotationClassMap;
import org.tinygroup.application.Application;
import org.tinygroup.application.ApplicationProcessor;
import org.tinygroup.parser.filter.NameFilter;
import org.tinygroup.xmlparser.node.XmlNode;

/**
 * 注解配置规范处理器
 * 
 * @author renhui
 * 
 */
public class AnnotationProcessor implements ApplicationProcessor {

	private static final String MAP_VALUE = "value";

	private static final String MAP_ID = "id";

	private static final String ANNOTATION_NODE_NAME = "annotation-configuration";

	private static final String ANNOTATION_MAPPING = "annotation-mapping";

	private XmlNode annotationNode;

	private Application application;

	public String getNodeName() {
		return ANNOTATION_NODE_NAME;
	}

	public void setConfiguration(XmlNode xmlNode) {
		this.annotationNode = xmlNode;
	}

	public XmlNode getConfiguration() {
		return annotationNode;
	}

	public void start() {
		NameFilter<XmlNode> nameFilter = new NameFilter<XmlNode>(annotationNode);
		List<XmlNode> nodes = nameFilter.findNodeList(ANNOTATION_MAPPING);
		for (XmlNode xmlNode : nodes) {
			AnnotationClassMap.putAnnotationMap(xmlNode.getAttribute(MAP_ID),
					xmlNode.getAttribute(MAP_VALUE));
		}
	}

	public void stop() {
		AnnotationClassMap.clearAnnotationMap();
	}

	public void setApplication(Application application) {
		this.application = application;
	}

}
