/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.applicationprocessor.processor;


import static org.tinygroup.logger.LogLevel.INFO;

import org.tinygroup.application.Application;
import org.tinygroup.application.ApplicationProcessor;
import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;
import org.tinygroup.xmlparser.node.XmlNode;

/**
 * 加载处理器，并执行加载
 * 
 * @author luoguo
 * 
 */
public class GreetingProcessor implements ApplicationProcessor {
	private static final String GREETINGS_NODE_NAME = "greetings";
	private static Logger logger = LoggerFactory
			.getLogger(GreetingProcessor.class);
	private XmlNode greetingNode;
	private Application application;

	public void setConfiguration(XmlNode greetingNode) {
		this.greetingNode = greetingNode;

	}

	private void showLogo() {
		logger.logMessage(INFO,
				"********************************************************");
		logger.logMessage(INFO,
				"  H U N D S U N   O P E N S O U R C E                   ");
		logger.logMessage(INFO,
				"********************************************************");
		logger.logMessage(INFO, "                       VERSIN 0.0.1          ");
		logger.logMessage(INFO,
				"********************************************************");
	}

	public void start() {
		if (greetingNode != null && greetingNode.getContent() != null) {
			String[] greetings = greetingNode.getContent().split("\n");
			for (String greeting : greetings) {
				greeting = greeting.trim();
				if (greeting.length() > 0) {
					logger.logMessage(INFO, greeting);
				}
			}
		} else {
			showLogo();
		}
	}

	public void stop() {

	}

	public String getNodeName() {
		return GREETINGS_NODE_NAME;
	}

	public XmlNode getConfiguration() {
		return greetingNode;
	}

	public void setApplication(Application application) {
		this.application=application;
		
	}
}
