/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.applicationprocessor.processor;

import org.tinygroup.application.Application;
import org.tinygroup.application.ApplicationProcessor;
import org.tinygroup.command.CommandSystem;
import org.tinygroup.command.ConsoleCommander;
import org.tinygroup.logger.LogLevel;
import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;
import org.tinygroup.xmlparser.node.XmlNode;

public class PluginCommandProcessor implements ApplicationProcessor {
	private static final String PLUGIN_COMMAND_NODE_NAME = "plugin-command";
	private static final String PLUGIN_INSTANCE_NAME = "plugin";// plugin.command.xml中的package-name
	private static Logger logger = LoggerFactory
			.getLogger(PluginCommandProcessor.class);
	private CommandSystem command;
	private ConsoleCommander consoleCommander;
	private Application application;

	public void setApplication(Application application) {
		this.application = application;

	}

	public void stop() {
		command.execute("destroy");
		if(consoleCommander!=null&&consoleCommander.isAlive()){
			consoleCommander.stopRead();
		}
	}

	public void start() {
		logger.logMessage(LogLevel.DEBUG, "启动插件命令行管理器");
		init();
		logger.logMessage(LogLevel.DEBUG, "启动插件命令行管理器成功");
	}

	private void init() {
		logger.logMessage(LogLevel.DEBUG, "初始化插件命令行管理器");
		command = CommandSystem.getInstance(PLUGIN_INSTANCE_NAME);
		consoleCommander = new ConsoleCommander(command);
		consoleCommander.start();
		logger.logMessage(LogLevel.DEBUG, "初始化插件命令行管理器成功");
	}

	public void setConfiguration(XmlNode xmlNode) {

	}

	public String getNodeName() {
		return PLUGIN_COMMAND_NODE_NAME;
	}

	public XmlNode getConfiguration() {
		return null;
	}

}
